@@ -728,10 +728,10 @@ class LossReserve:
         """
         self._reserve_by_ay_fl()
         ay_ = np.arange(0, self.predicted_i_payments.shape[0])
-        data = np.dstack((ay_, np.round(self.ay_ultimateFL), np.round(self.ay_reserveFL))).reshape(-1, 3)
+        data = np.dstack((ay_, np.round(self.ay_ultimateFL, 2), np.round(self.ay_reserveFL, 2))).reshape(-1, 3)
         if self.reserving_method == 'crm':
-            data2 = np.dstack((np.round(self.crm_ul_ay), np.round(self.ay_reserve_crm), np.round(
-                self.crm_sep_ay))).reshape(-1, 3)
+            data2 = np.dstack((np.round(self.crm_ul_ay, 2), np.round(self.ay_reserve_crm, 2), np.round(
+                self.crm_sep_ay, 2))).reshape(-1, 3)
             data = np.column_stack((data, data2))
         l_ = ['time', 'ultimate FL', 'reserve FL']
         if self.reserving_method == 'crm':
@@ -746,10 +746,10 @@ class LossReserve:
             "===================================================================="]))
         for row in data:
             print(s_.format("", *row))
-        print('\n FL reserve: ', self.fl_reserve)
+        print('\n FL reserve: ', np.round(self.fl_reserve, 2))
         if self.reserving_method == 'crm':
-            print('\n CRM reserve: ', self.crm_reserve)
-            print('\n CRM m_sep: ', self.m_sep)
+            print('\n CRM reserve: ', np.round(self.crm_reserve, 2))
+            print('\n CRM m_sep: ', np.round(self.m_sep, 2))
 
     def loss_reserve_mean(self):
         """
